//++
//id3.h - declarations for id3.c module
//
// Copyright (C) 2005 by Spare Time Gizmos.  All rights reserved.
//
// This file is part of the Spare Time Gizmos' MP3 Player firmware.
//
// This firmware is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2 of the License, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// this program; if not, write to the Free Software Foundation, Inc., 59 Temple
// Place, Suite 330, Boston, MA  02111-1307  USA
//
//REVISION HISTORY:
// dd-mmm-yy    who     description
// 26-May-05	RLA	New file.
// 19-Oct-05	RLA	Add prototype for ReadID3Tag().
//			Add declarations for g_szArtistName[] and g_szTrackName[]
// 			Add STACKSLOCS hack to ReadID3Tag() for SDCC.
//--
#ifndef _id3_h_
#define _id3_h_
#include "slocs.h"	// STACKSLOCS hack for SDCC

// This is the basic structure of an ID3 v1.1 tag...
#define ID3_MAX_ARTIST_NAME	30
#define ID3_MAX_TRACK_NAME	30
struct _ID3_TAG {        
  char abID3[3];	 		 // "ID3" for a valid tag
  char szTrackName[ID3_MAX_TRACK_NAME];	 // track name string
  char szArtistName[ID3_MAX_ARTIST_NAME];// artist name string
  char szAlbumName[30];	 		 // album name string
  BYTE abYear[4];	 		 // year (in ASCII text)
  char szComment[28];	 		 // comment string
  char bSeparator;	 		 // always zero
  BYTE bTrackNumber;	 		 // track number (in binary)		
  BYTE bGenre;		 		 // Genre code
};
typedef struct _ID3_TAG ID3_TAG;
typedef struct _ID3_TAG XDATA *PXID3TAG;
#define ID3_TAG_SIZE		(sizeof(ID3_TAG))

// Members...
extern XDATA char g_szArtistName[ID3_MAX_ARTIST_NAME];
extern XDATA char g_szTrackName[ID3_MAX_TRACK_NAME];

// Methods...
extern BOOL ReadID3Tag (PXDIRENT pxDirEnt) STACKSLOCS;

#endif	// _id3_h_
